pub struct DefaultValueParser<'a> {
link_resolver: &'a LinkResolver<'a>,
current_module: &'a str,
}Expand description
Parser for default values that identifies and links type references
Fields
link_resolver: &'a LinkResolver<'a>current_module: &'a strImplementations
Sourceimpl<'a> DefaultValueParser<'a>
impl<'a> DefaultValueParser<'a>
pub fn new(link_resolver: &'a LinkResolver<'a>, current_module: &'a str) -> Self
Sourcepub fn parse(&self, default_str: &str, type_info: &TypeInfo) -> DocDefaultValue
pub fn parse(&self, default_str: &str, type_info: &TypeInfo) -> DocDefaultValue
Parse a default value string and identify type references
Sourcefn strip_module_prefixes(&self, text: &str) -> String
fn strip_module_prefixes(&self, text: &str) -> String
Strip module prefixes like “_core.”, “typing.”, “builtins.” from the display text
Sourcefn try_parse_attribute_ref(
&self,
text: &str,
_type_info: &TypeInfo,
) -> Option<DocTypeRef>
fn try_parse_attribute_ref( &self, text: &str, _type_info: &TypeInfo, ) -> Option<DocTypeRef>
Try to parse an attribute reference like “C.C1”